pylero.cli package — pylero documentation

# pylero.cli package

## Submodules

## pylero.cli.cmd module

class pylero.cli.cmd.CmdList

  Bases: `object`

  An object to manage the command of list

  list_documents_by_query(query)
  list_workitems_by_query(query, wi_type)
  list_workitems_in_doc(doc_name_with_space)
  print_documents(docs)
  print_links_for_requirement(req_id)
  print_links_for_testcase(case_id)
  print_plan_ids(query)
  print_runs_by_query(query, is_template=False)
  print_steps_for_testcase(case_id)
  print_templates_by_query(query)
  print_testcases_from_run(run)
  print_workitems(workitems)

class pylero.cli.cmd.CmdUpdate

  Bases: `object`

  An object to manage the command of update

  update_1_case_result_for_run(run, testcase, result, user, comment)
  update_all_case_results_for_run(run, result, user, comment)
  update_all_case_results_for_runs(runs, result, user, comment)
  update_document(space, doc_name, doc_title, wi_types=None, doc_type=None, structure_link_role='parent', content='')
  update_run(run, template=None, plannedin=None, assignee=None, status=None, description=None, is_template=False)
  update_runs(runs, template=None, plannedin=None, assignee=None, status=None, description=None)

## Module contents